.. index:: examples_index

.. _examples_index:

Tutorials and example notebooks
===============================

Real use-cases
--------------

- `Harper et al, Research Data Accompanying "Computational Discovery of Novel Copper Phosphide Conversion Anode for Lithium-Ion Batteries" <https://github.com/harpaf13/data.copper-phosphides>`_. |CuP Binder|

Example Jupyter notebooks
-------------------------

.. toctree::

    notebooks/hull
    notebooks/matador_plot_styles
    notebooks/voltage_from_res_files
    notebooks/simple_spectral
    notebooks/projected_spectral
    notebooks/projected_spectral_as_subplots
    notebooks/phonon_results
    notebooks/pxrd_plotting
    notebooks/magres_plotting
    notebooks/pymatgen_and_ase_interface

Tutorials
---------

.. toctree::
    :maxdepth: 2

    tutorials/run3
    tutorials/mongo

.. |CuP Binder| image:: https://mybinder.org/badge_logo.svg
   :target: https://mybinder.org/v2/gh/harpaf13/data.copper-phosphides/master?filepath=CuP_results.ipynb
